diff --git a/src/Graphics/Resources/Buffer.cs b/src/Graphics/Resources/Buffer.cs
index 63814a07..1d653b1c 100644
--- a/src/Graphics/Resources/Buffer.cs
+++ b/src/Graphics/Resources/Buffer.cs
@@ -61,14 +61,14 @@ namespace MoonWorks.Graphics
/// Reads data out of a buffer and into an array.
/// This operation is only guaranteed to read up-to-date data if GraphicsDevice.Wait is called first.
///
/// The array that data will be copied to.
/// The length of the data to read.
public unsafe void GetData(
- T[] data,
+ Span data,
uint dataLengthInBytes
) where T : unmanaged
{
- fixed (T* ptr = &data[0])
+ fixed (T* ptr = data)
{
Refresh.Refresh_GetBufferData(
Device.Handle,
@@ -61,14 +61,14 @@ namespace MoonWorks.Graphics
/// This operation is only guaranteed to read up-to-date data if GraphicsDevice.Wait is called first.
///
- /// The array that data will be copied to.
+ /// The span that data will be copied to.
/// The length of the data to read.
public unsafe void GetData(